module write_aux_m

  implicit none

contains

  subroutine write_aux(corner_deg, step_deg, nlon, nlat, hshpc, exist, shpc_dir)

    ! Write auxiliary files "grid_nml.txt" and "ishape_last.txt".

    ! Libraries:
    use jumble, only: new_unit
    use shapelib_03, only: shp_get_info_03

    use derived_types, only: shpc

    ! Note: we do not use assumed-shape arrays here for corner_deg and
    ! step_deg because of an internal compiler error of ifort
    ! 19.0. The bug seems corrected in ifort 19.1. Assumed-shape
    ! arrays are allowed in a namelist in Fortran 2003.

    real, intent(in):: corner_deg(2)
    ! longitude and latitude of the corner of the whole grid, in degrees

    real, intent(in):: step_deg(2)
    ! longitude and latitude steps, in degrees

    integer, intent(in):: nlon, nlat
    ! size of ssh array in input NetCDF, assuming no repeated point if
    ! the grid is global

    TYPE(shpc), intent(in):: hshpc
    logical, intent(in):: exist
    character(len = *), intent(in):: shpc_dir

    ! Local:
    namelist /grid_nml/ corner_deg, step_deg, nlon, nlat
    integer unit, n_entities

    !--------------------------------------------------------------------

    call shp_get_info_03(hshpc%extremum, n_entities)
    call new_unit(unit)

    if (exist) then
       open(unit, file = shpc_dir // "/ishape_last.txt", status = "old", &
            action = "write", position = "append")
       write(unit, fmt = *) n_entities - 1
       close(unit)
    else
       open(unit, file = shpc_dir // "/grid_nml.txt", status = "replace", &
            action = "write")
       write(unit, nml = grid_nml)
       close(unit)
       open(unit, file = shpc_dir // "/ishape_last.txt", status = "replace", &
            action = "write")
       write(unit, fmt = *) n_entities - 1
       close(unit)
    end if

  end subroutine write_aux
  
end module write_aux_m
